==> open-autonomy-0.1.1.tar.gz: open-autonomy-0.1.1/packages/valory/protocols/tendermint/dialogues.py <==
# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2022 valory
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

"""
This module contains the classes required for tendermint dialogue management.

- TendermintDialogue: The dialogue class maintains state of a dialogue and manages it.
- TendermintDialogues: The dialogues class keeps track of all dialogues.
"""

from abc import ABC
from typing import Callable, Dict, FrozenSet, Type, cast

from aea.common import Address
from aea.protocols.base import Message
from aea.protocols.dialogue.base import Dialogue, DialogueLabel, Dialogues

from packages.valory.protocols.tendermint.message import TendermintMessage


class TendermintDialogue(Dialogue):
    """The tendermint dialogue class maintains state of a dialogue and manages it."""

    INITIAL_PERFORMATIVES: FrozenSet[Message.Performative] = frozenset(
        {TendermintMessage.Performative.TENDERMINT_CONFIG_REQUEST}
    )
    TERMINAL_PERFORMATIVES: FrozenSet[Message.Performative] = frozenset(
        {
            TendermintMessage.Performative.TENDERMINT_CONFIG_RESPONSE,
            TendermintMessage.Performative.ERROR,
        }
    )
    VALID_REPLIES: Dict[Message.Performative, FrozenSet[Message.Performative]] = {
        TendermintMessage.Performative.ERROR: frozenset(),
        TendermintMessage.Performative.TENDERMINT_CONFIG_REQUEST: frozenset(
            {
                TendermintMessage.Performative.TENDERMINT_CONFIG_RESPONSE,
                TendermintMessage.Performative.ERROR,
            }
        ),
        TendermintMessage.Performative.TENDERMINT_CONFIG_RESPONSE: frozenset(),
    }

    class Role(Dialogue.Role):
        """This class defines the agent's role in a tendermint dialogue."""

        AGENT = "agent"

    class EndState(Dialogue.EndState):
        """This class defines the end states of a tendermint dialogue."""

        CONFIG_SHARED = 0
        CONFIG_NOT_SHARED = 1

    def __init__(
        self,
        dialogue_label: DialogueLabel,
        self_address: Address,
        role: Dialogue.Role,
        message_class: Type[TendermintMessage] = TendermintMessage,
    ) -> None:
        """
        Initialize a dialogue.

        :param dialogue_label: the identifier of the dialogue
        :param self_address: the address of the entity for whom this dialogue is maintained
        :param role: the role of the agent this dialogue is maintained for
        :param message_class: the message class used
        """
        Dialogue.__init__(
            self,
            dialogue_label=dialogue_label,
            message_class=message_class,
            self_address=self_address,
            role=role,
        )


class TendermintDialogues(Dialogues, ABC):
    """This class keeps track of all tendermint dialogues."""

    END_STATES = frozenset(
        {
            TendermintDialogue.EndState.CONFIG_SHARED,
            TendermintDialogue.EndState.CONFIG_NOT_SHARED,
        }
    )

    _keep_terminal_state_dialogues = True

    def __init__(
        self,
        self_address: Address,
        role_from_first_message: Callable[[Message, Address], Dialogue.Role],
        dialogue_class: Type[TendermintDialogue] = TendermintDialogue,
    ) -> None:
        """
        Initialize dialogues.

        :param self_address: the address of the entity for whom dialogues are maintained
        :param dialogue_class: the dialogue class used
        :param role_from_first_message: the callable determining role from first message
        """
        Dialogues.__init__(
            self,
            self_address=self_address,
            end_states=cast(FrozenSet[Dialogue.EndState], self.END_STATES),
            message_class=TendermintMessage,
            dialogue_class=dialogue_class,
            role_from_first_message=role_from_first_message,
        )

==> open-autonomy-0.10.2.tar.gz: open-autonomy-0.10.2/packages/valory/protocols/tendermint/dialogues.py <==
# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2023 valory
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

"""
This module contains the classes required for tendermint dialogue management.

- TendermintDialogue: The dialogue class maintains state of a dialogue and manages it.
- TendermintDialogues: The dialogues class keeps track of all dialogues.
"""

from abc import ABC
from typing import Callable, Dict, FrozenSet, Type, cast

from aea.common import Address
from aea.protocols.base import Message
from aea.protocols.dialogue.base import Dialogue, DialogueLabel, Dialogues

from packages.valory.protocols.tendermint.message import TendermintMessage


class TendermintDialogue(Dialogue):
    """The tendermint dialogue class maintains state of a dialogue and manages it."""

    INITIAL_PERFORMATIVES: FrozenSet[Message.Performative] = frozenset(
        {
            TendermintMessage.Performative.GET_GENESIS_INFO,
            TendermintMessage.Performative.GET_RECOVERY_PARAMS,
        }
    )
    TERMINAL_PERFORMATIVES: FrozenSet[Message.Performative] = frozenset(
        {
            TendermintMessage.Performative.GENESIS_INFO,
            TendermintMessage.Performative.RECOVERY_PARAMS,
            TendermintMessage.Performative.ERROR,
        }
    )
    VALID_REPLIES: Dict[Message.Performative, FrozenSet[Message.Performative]] = {
        TendermintMessage.Performative.ERROR: frozenset(),
        TendermintMessage.Performative.GENESIS_INFO: frozenset(),
        TendermintMessage.Performative.GET_GENESIS_INFO: frozenset(
            {
                TendermintMessage.Performative.GENESIS_INFO,
                TendermintMessage.Performative.ERROR,
            }
        ),
        TendermintMessage.Performative.GET_RECOVERY_PARAMS: frozenset(
            {
                TendermintMessage.Performative.RECOVERY_PARAMS,
                TendermintMessage.Performative.ERROR,
            }
        ),
        TendermintMessage.Performative.RECOVERY_PARAMS: frozenset(),
    }

    class Role(Dialogue.Role):
        """This class defines the agent's role in a tendermint dialogue."""

        AGENT = "agent"

    class EndState(Dialogue.EndState):
        """This class defines the end states of a tendermint dialogue."""

        COMMUNICATED = 0
        NOT_COMMUNICATED = 1

    def __init__(
        self,
        dialogue_label: DialogueLabel,
        self_address: Address,
        role: Dialogue.Role,
        message_class: Type[TendermintMessage] = TendermintMessage,
    ) -> None:
        """
        Initialize a dialogue.

        :param dialogue_label: the identifier of the dialogue
        :param self_address: the address of the entity for whom this dialogue is maintained
        :param role: the role of the agent this dialogue is maintained for
        :param message_class: the message class used
        """
        Dialogue.__init__(
            self,
            dialogue_label=dialogue_label,
            message_class=message_class,
            self_address=self_address,
            role=role,
        )


class TendermintDialogues(Dialogues, ABC):
    """This class keeps track of all tendermint dialogues."""

    END_STATES = frozenset(
        {
            TendermintDialogue.EndState.COMMUNICATED,
            TendermintDialogue.EndState.NOT_COMMUNICATED,
        }
    )

    _keep_terminal_state_dialogues = True

    def __init__(
        self,
        self_address: Address,
        role_from_first_message: Callable[[Message, Address], Dialogue.Role],
        dialogue_class: Type[TendermintDialogue] = TendermintDialogue,
    ) -> None:
        """
        Initialize dialogues.

        :param self_address: the address of the entity for whom dialogues are maintained
        :param dialogue_class: the dialogue class used
        :param role_from_first_message: the callable determining role from first message
        """
        Dialogues.__init__(
            self,
            self_address=self_address,
            end_states=cast(FrozenSet[Dialogue.EndState], self.END_STATES),
            message_class=TendermintMessage,
            dialogue_class=dialogue_class,
            role_from_first_message=role_from_first_message,
        )
